#line 1 "trafgen/trafgen_lexer.yy.c"

#line 3 "trafgen/trafgen_lexer.yy.c"

#define  YY_INT_ALIGNED long int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 155
#define YY_END_OF_BUFFER 156
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int32_t yy_accept[673] =
    {   0,
      140,  140,  156,  154,  140,  138,  140,  154,  142,  123,
      124,  154,  131,  132,  121,  120,  135,  119,  122,  144,
      144,  144,  136,  153,  126,  137,  127,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      133,  134,  128,  129,  125,  130,  140,  140,  123,  124,
      121,  120,  119,  122,  126,  127,  128,  125,    0,  142,
      123,  124,    0,    0,  121,  120,  119,  122,    0,    0,
      145,    0,    0,    0,    0,  144,    0,   36,  150,  153,
      126,  127,   86,    0,    0,    0,    0,    0,    0,  146,

        0,    0,    0,   19,    0,    0,    0,    0,    0,    0,
        0,   25,    0,    0,   60,    0,    0,    0,   71,    0,
        0,    0,    0,    0,    0,   62,    0,   64,    0,    0,
        0,   56,    0,    0,    0,    0,    0,   61,    0,    0,
        0,    0,   63,  103,   46,    0,    0,    0,    0,    0,
        0,    0,   85,    0,    0,   91,    0,    0,    0,    0,
       26,    0,    0,    0,    0,   70,    0,   24,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  143,    0,  128,  125,  139,  152,    0,    0,    0,
        0,  145,    0,    0,  150,  146,  144,   35,  150,    0,

       78,  102,    0,  100,    0,  111,    0,    0,   20,   21,
       22,   34,    0,    0,    0,    0,    1,    0,   75,    0,
        0,    0,   34,    0,  118,    0,    0,    0,    0,   76,
        0,   53,  106,    0,   39,    0,   82,    0,    0,    0,
        0,    0,    0,    0,   49,  112,  113,    0,    0,    0,
       37,   55,    0,   66,    0,    0,    0,    0,    0,   33,
      108,   30,    0,   79,  105,    0,    0,   99,    0,    0,
        0,    0,    0,   44,    3,   80,    0,   72,   40,   41,
        0,   41,    0,   81,   32,    0,  117,   42,    0,   43,
        0,   54,   43,    0,    0,   51,    0,  116,   77,   50,

        0,   83,    0,    0,  141,    0,  145,    0,    0,    0,
      150,  146,  144,  150,    0,    0,    0,   65,    0,    0,
        0,   73,  101,    0,    0,   67,    0,   59,    0,   98,
       16,   15,   74,    0,   14,   52,    0,    0,    2,    0,
       62,   58,   74,    0,    0,    0,    0,   38,    0,  110,
       96,    0,    0,   46,    0,   30,   23,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   40,    0,
        0,   29,   42,   31,    0,   28,    0,    0,  109,    0,
       90,    0,    0,  145,    0,    0,    0,  150,  150,    0,
      146,  144,  150,  150,    0,    0,    0,    0,    0,   97,

      104,    0,    0,    0,    0,    0,   25,   71,    0,   27,
       57,    0,   47,  114,  115,    0,   37,    0,    0,    0,
      107,   23,   48,    0,   99,    0,   91,    0,   45,    0,
       26,    0,    0,   70,    0,   87,    0,    0,    0,  151,
        0,    0,    0,    0,    0,  150,  150,  150,  150,  150,
        0,    0,   73,    0,  100,    0,    0,    0,    0,   19,
        4,    0,    5,    0,    0,    0,    0,   55,    0,    0,
        0,   88,    0,    0,   18,   17,   24,   84,    0,   83,
      149,    0,    0,    0,  150,  150,    0,  150,  150,    0,
      150,  150,   86,   93,   95,   20,   21,   22,    0,    6,

       10,    9,    0,    0,    0,   63,   94,   92,    0,   44,
       50,    0,    0,    0,    0,  150,  150,  150,  150,  150,
      150,  150,    0,    7,   12,   11,    0,    0,   64,   89,
        0,    0,    0,  150,  150,    0,  150,  150,    0,  150,
      150,    0,  150,  150,    8,   13,   69,    0,    0,    0,
        0,    0,  150,  150,  150,  150,  150,  150,  150,  150,
      150,    0,    0,    0,    0,  148,  150,  150,    0,  150,
      150,    0,  150,  150,    0,  150,  150,    0,  150,  150,
       68,    0,    0,  148,    0,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,    0,    0,  148,    0,

      150,  150,    0,  150,  150,    0,  150,  150,    0,  150,
      150,    0,  150,  150,    0,  150,  150,    0,  148,    0,
        0,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,    0,  148,    0,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,  150,    0,  150,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      150,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    6,    1,    7,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   23,   25,   23,   26,   27,   28,
       29,   30,    1,    1,   31,   32,   33,   34,   35,   36,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   58,   59,   60,    1,    1,   61,   62,   63,   64,

       65,   66,   67,   68,   69,   40,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
       84,   85,   86,   87,   88,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[89] =
    {   0,
        1,    1,    2,    1,    3,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    4,    4,    4,
        4,    4,    4,    4,    4,    5,    1,    1,    1,    1,
        4,    4,    4,    4,    4,    4,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        4,    4,    4,    4,    4,    4,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1
    } ;

static const flex_int32_t yy_base[827] =
    {   0,
        0,    0, 1536, 1537,   87,   90,   93,    0,    0, 1531,
     1530, 1475, 1537, 1537, 1528, 1527, 1537, 1526,   95,  165,
      233,   67, 1503,    0, 1524, 1537, 1523,  292,   85,  355,
      420,   76,   92, 1537,   70,  104,  142,  159,  270,   70,
      442,  160,  478,  526,  578,   88,  171,   78,    0,   89,
     1537, 1537, 1522, 1537, 1521, 1537,  154,  274, 1520, 1519,
     1518, 1517, 1516, 1515, 1514, 1513, 1512, 1511, 1509,    0,
     1509, 1508, 1502,  110, 1506, 1505, 1504, 1503, 1494,  510,
      647, 1479,  555,  114,    0,  584,  112, 1537,    0,    0,
     1500, 1499,  148,  169,  114,  169,  187,  147,  164,  152,

     1478, 1481, 1478,    0,  176,  185,  210,  256,  193,  212,
      226,  287,  287,  291,    0,  289,  290,  327,  297,  323,
      331,  472,  347,  336,  361,  353,  352,  357,  349,  351,
      364, 1537,  405,  436,  418,  406,  426, 1537,  429,  421,
      472,  464, 1537,  416,  422,  472,  478,  441,  515,  468,
      515,  492,  483,  523,  516,  538,  531,  539,  556,  543,
      566,  566,  587,  579,  588,  600,  583,  645,  598,  643,
      603,  626,  661,  625,  635,  642,  644,  656,  647,  665,
      654,    0,  651, 1495, 1494, 1537, 1537,    0, 1485, 1479,
      713,  723,  744, 1469,    0,  204,  752,    0, 1468,  672,

      702,  704,  708,  708,  733, 1537,  732,  745,    0,    0,
        0, 1537,  742,  749,  758,  746, 1537,  753, 1537,  763,
      767,  766, 1537,  767, 1537,  765,  755,  770,  760,    0,
      764, 1537, 1537,  764, 1537,  769, 1537,  775,  761,  778,
      773,  776,  773,  776, 1537, 1537, 1537,  103,  791,  783,
     1537,  799,  792, 1537,  802,  794,  804,  802,  803, 1537,
     1537,  808,  804, 1537, 1537,  809,  812, 1537,  810,  828,
      826,  814,  822,  814, 1537, 1537,  827,  835, 1537, 1537,
      835, 1537,  823, 1537, 1537,  841, 1537, 1537,  840, 1537,
      843, 1537, 1537,  843,  836, 1537,  850, 1537,  842,  846,

      852,  863,  856,    0, 1537,  913,  923,  944, 1467, 1466,
     1465,  242,  952, 1464,    0,  858,  885, 1537,  871,  888,
      901, 1537, 1537,  912,  943, 1537,  930,  960,  935, 1537,
        0, 1537, 1537,  941, 1537, 1537,  944,  958, 1537,  946,
     1537, 1537, 1537,  957,  962,  976,  959, 1537,  952, 1537,
     1537,  965,  954, 1537,  971, 1537,  968,  972,  963,  960,
      977,  982,  979,  967,  984,  977,  997,  991, 1537,  988,
      992, 1537, 1537, 1537, 1012, 1537, 1000, 1013, 1537, 1010,
     1537, 1480, 1067, 1462, 1461, 1460, 1459,    0, 1458,    0,
      617, 1457, 1456, 1455, 1028, 1018, 1022, 1020, 1025, 1537,

     1537,  325, 1456, 1063, 1038, 1038, 1537, 1537, 1038, 1537,
     1537, 1033, 1537, 1537, 1537,  138, 1537, 1036, 1043, 1037,
     1537, 1537, 1537, 1055, 1537, 1058, 1537, 1058, 1537, 1059,
     1537, 1078, 1079, 1537, 1065, 1537, 1067, 1071, 1064, 1537,
     1100,    0, 1453, 1452, 1451, 1450, 1449, 1448, 1447, 1446,
        0, 1079, 1537, 1080, 1537, 1081, 1447, 1450, 1447, 1537,
     1537, 1089, 1446, 1087, 1088, 1093, 1097, 1537, 1099, 1098,
     1099, 1537, 1115, 1102, 1537, 1537, 1537, 1537, 1109, 1537,
     1165, 1441, 1440, 1439,    0, 1438,    0, 1437, 1436,    0,
     1435, 1434, 1537, 1537, 1537, 1537, 1537, 1537, 1118, 1537,

     1435, 1434, 1123, 1116, 1120, 1537, 1537, 1537, 1137, 1537,
     1537,    0, 1431, 1430, 1429, 1428, 1427, 1426, 1425, 1424,
     1423, 1422,    0,  248, 1537, 1537, 1118, 1139, 1537, 1537,
     1421, 1420, 1419,    0, 1418,    0, 1417, 1416,    0, 1415,
     1414,    0, 1413, 1412, 1537, 1537, 1537, 1130,    0, 1411,
     1410, 1409, 1408, 1407, 1406, 1405, 1404, 1403, 1402, 1401,
     1400,    0, 1141, 1399, 1398, 1211,    0, 1206,    0, 1201,
     1197,    0, 1193, 1192,    0, 1191, 1190,    0, 1189, 1188,
     1537,    0, 1187, 1186, 1185, 1184, 1183, 1181, 1180, 1179,
     1177, 1174, 1172, 1171, 1169, 1166,    0, 1149, 1146, 1132,

        0, 1131,    0, 1129, 1128,    0, 1125, 1087,    0, 1054,
     1052,    0, 1035, 1034,    0, 1033, 1032,    0, 1030, 1027,
      978,    0,  968,    0,  956,    0,  903,    0,  902,    0,
      900,    0,  895,  893,    0,    0,  892,    0, 1537,    0,
      890,    0,  888,    0,  887,    0,  886,    0,  884,    0,
      882,    0,  877,    0,    0,    0,    0,    0,    0,    0,
      790,    0,    0, 1537, 1537, 1537, 1537, 1537, 1537,    0,
     1537, 1537, 1220, 1225, 1230, 1235, 1237,  801, 1242, 1244,
      798,  790, 1246,  736, 1248,  721, 1250, 1252, 1254, 1256,
      703, 1258, 1260,  699, 1262,  698, 1264, 1266,  697, 1268,

     1270, 1272, 1274, 1276, 1278,  693, 1280, 1282,  690, 1284,
      681, 1286,  656, 1288, 1290,  654, 1292, 1294, 1296, 1298,
     1300, 1302, 1304, 1306,  647, 1308, 1310,  640, 1312,  636,
     1314,  635, 1316,  634, 1318, 1320,  633, 1322, 1324, 1326,
     1328, 1330, 1332, 1334, 1336, 1338, 1340,  628, 1342, 1344,
      578, 1346,  558, 1348,  555, 1350,  546, 1352,  545, 1354,
     1356,  544, 1358, 1360, 1362, 1364, 1366, 1368, 1370, 1372,
     1374, 1376, 1378, 1380,  542, 1382, 1384,  522, 1386,  510,
     1388,  498, 1390,  459, 1392,  458, 1394,  457, 1396, 1398,
      421, 1400, 1402,  419, 1404,  408, 1406,  406, 1408,  405,

     1410,  355, 1412,  343, 1414,  341, 1416,  328,  303,  302,
      289,  284,  281,  280, 1418,  279,  275,  271,  231,  213,
      171,  162,  147,  131,  125,  109
    } ;

static const flex_int32_t yy_def[827] =
    {   0,
      672,    1,  672,  672,  672,  672,  672,  673,  674,  672,
      672,  675,  672,  672,  672,  672,  672,  672,  672,  672,
      672,   21,  672,  676,  672,  672,  672,  672,  677,  672,
      672,  677,  677,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  678,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  673,  674,
      672,  672,  672,  672,  672,  672,  672,  672,  679,  672,
      672,  680,   81,   83,  678,   81,   83,  672,  681,  676,
      672,  672,   83,   83,   83,  672,  672,  672,  672,   83,

       83,   83,   83,   83,   83,  672,  672,  672,  672,  672,
      672,   83,   83,   83,   83,  672,  672,  672,  672,  672,
      672,   83,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  678,  672,  672,  672,  672,  672,  682,  679,  679,
      672,  672,  192,  683,  684,  193,  192,  193,  685,  672,

      672,  193,  672,  672,  672,  672,  672,  672,  193,  193,
      193,  672,  672,  672,  672,  672,  672,  672,  672,  193,
      672,  193,  672,  672,  672,  672,  672,  672,  672,  193,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  686,  672,  672,  672,  307,  687,  688,
      689,  308,  307,  690,  691,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  308,  672,
      308,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  307,  308,  692,  693,  694,  695,  696,
      308,  313,  697,  698,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  699,  699,  700,  701,  702,  703,  704,  672,  705,
      706,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  699,  707,  708,  709,  710,  711,  672,  712,  713,
      714,  715,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  716,  716,  717,  718,  719,  720,  721,  722,  723,
      672,  724,  725,  672,  672,  672,  672,  672,  672,  672,
      716,  726,  727,  728,  729,  730,  672,  731,  732,  672,
      733,  734,  735,  736,  672,  672,  672,  672,  737,  737,
      738,  739,  740,  741,  742,  743,  744,  745,  746,  672,
      747,  748,  672,  737,  749,  750,  751,  752,  753,  672,
      754,  755,  672,  756,  757,  672,  758,  759,  760,  761,
      672,  762,  762,  763,  764,  765,  766,  767,  768,  769,
      770,  771,  772,  773,  672,  774,  775,  762,  776,  777,

      778,  779,  780,  672,  781,  782,  672,  783,  784,  672,
      785,  786,  672,  787,  788,  789,  790,  791,  791,  792,
      793,  794,  795,  796,  797,  798,  799,  800,  801,  802,
      803,  804,  672,  805,  806,  791,  807,  808,  672,  809,
      672,  810,  672,  811,  672,  812,  672,  813,  672,  814,
      815,  816,  672,  817,  818,  819,  820,  821,  822,  823,
      672,  824,  825,  672,  672,  672,  672,  672,  672,  826,
      672,    0,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672
    } ;

static const flex_int32_t yy_nxt[1626] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,    4,   19,   20,   21,   22,
       22,   22,   22,   22,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   34,
       34,   37,   38,   39,   40,   41,   42,   43,   44,   45,
       46,   47,   48,   49,   34,   50,   51,    4,   52,   53,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   34,
       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,   34,   50,   54,   55,   56,   57,   57,
       57,   57,   57,   57,   57,   57,   58,   83,   78,   59,

       60,   82,  100,  100,   61,   62,   79,   63,  122,   64,
       82,  128,  639,  672,  129,  145,  181,   82,  187,  130,
       65,  177,   66,  183,  246,  123,  247,   83,  671,  124,
      125,  196,  196,  126,  670,  178,  131,  132,  122,  127,
      128,  133,  672,  129,  145,  198,  181,  202,  130,  134,
      669,  177,   67,  183,  123,   57,   57,   57,  124,  414,
      125,  415,  126,  188,  178,  668,  131,  132,  127,  196,
      196,  133,  135,  136,  667,  198,  137,  202,  134,   68,
       80,  207,   81,   81,   81,   81,   81,   81,   81,   81,
       82,  200,  188,  152,  138,   83,   84,   83,   83,   83,

       83,  203,  135,  136,  139,  179,  137,  153,  140,  201,
      154,  207,  180,  208,  212,  213,  666,  204,   85,  205,
      200,  312,  312,  152,  138,   83,   84,   83,   83,   83,
       83,  203,  206,  139,  665,  179,  153,  140,  201,  154,
      214,  180,  208,  217,  212,  213,  204,   85,   80,  205,
       86,   86,   86,   86,   86,   86,   86,   86,   82,  391,
      391,  206,  218,   87,   83,   83,   83,   83,   83,  545,
      214,  546,  217,  219,  664,   57,   57,   58,  663,   88,
       59,   60,  662,  660,  659,   61,   62,  658,   63,  215,
       64,  218,  657,   87,   83,   83,   83,   83,   83,  216,

      141,   65,  219,   66,  142,  656,  655,  143,   88,   83,
       83,   83,   83,   83,   83,   83,   83,   82,  144,  215,
      220,  222,   93,   83,   94,   95,   83,   83,  216,  223,
      141,  654,  224,   67,  142,   96,  221,  143,  225,   97,
       98,  227,   99,  457,  652,  458,  650,  144,  459,  460,
      220,  222,   93,   83,   94,   95,   83,   83,  648,  223,
       68,  224,  226,  229,   96,  221,  228,  225,   97,   98,
      227,   99,   83,  101,   83,  102,   83,   83,  103,  104,
       82,  235,  240,  238,  233,   83,   83,   83,   83,   83,
      105,  241,  226,  229,  242,  228,  106,  239,  107,  108,

      109,  234,  236,  110,  237,  243,  244,  111,  646,  644,
      235,  642,  240,  238,  233,   83,   83,   83,   83,   83,
      105,  241,  640,  242,  636,  106,  239,  107,  108,  109,
      234,  236,  110,  237,  243,  244,  111,   83,   83,   83,
       83,   83,   83,   83,   83,   82,  245,  251,  257,  249,
      112,   83,   83,  113,  114,  115,  258,  246,  116,  247,
      632,  630,  628,  117,  118,  119,  250,  120,  121,  252,
      253,  254,  146,  261,  147,  245,  251,  148,  257,  249,
      112,   83,   83,  113,  114,  115,  258,  248,  116,  149,
      150,  151,  117,  118,  119,  250,  120,  121,  252,  253,

      254,  626,  146,  261,  147,  264,  230,  148,  155,  231,
      156,  157,  158,  624,  255,  232,  248,  256,  149,  150,
      151,  159,  259,  260,  267,  622,  160,  191,  191,  191,
      191,  191,  191,  191,  191,  264,  230,  268,  155,  231,
      156,  157,  158,  255,  232,  617,  256,  598,  594,  592,
      159,  259,  260,  262,  267,  160,  161,  269,  590,  263,
      162,  588,  265,  163,  164,  272,  268,  270,  165,  266,
      672,  166,  193,  193,  193,  193,  193,  193,  193,  193,
      167,  586,  271,  262,  273,  274,  161,  269,  263,  275,
      162,  265,  276,  163,  164,  272,  270,  165,  266,  277,

      166,  197,  197,  197,  197,  197,  197,  197,  197,  167,
      168,  271,  278,  273,  274,  169,  170,  279,  281,  275,
      171,  276,  172,  173,  280,  174,  284,  175,  288,  277,
      282,  580,  176,  291,  391,  391,  564,  559,  557,  555,
      168,  278,  442,  553,  283,  169,  170,  279,  281,  171,
      544,  172,  173,  280,  174,  284,  175,  531,  288,  520,
      282,  176,   80,  291,  192,  192,  192,  192,  192,  192,
      192,  192,   82,  283,  292,  295,  296,  193,  193,  193,
      193,  193,  193,  285,  518,  289,  286,  297,  290,  298,
      287,  293,  299,  516,  300,  301,  492,  302,  303,  294,

      482,  448,  446,  292,  295,  296,  394,  193,  193,  193,
      193,  193,  193,  285,  289,  286,  297,  290,  298,  287,
      316,  293,  299,  300,  382,  301,  302,  303,  306,  294,
      191,  191,  191,  191,  191,  191,  191,  191,   80,  311,
      307,  307,  307,  307,  307,  307,  307,  307,   82,  316,
      317,  318,  319,  308,  308,  308,  308,  308,  308,  672,
      320,  308,  308,  308,  308,  308,  308,  308,  308,  313,
      313,  313,  313,  313,  313,  313,  313,  321,  322,  317,
      318,  319,  323,  308,  308,  308,  308,  308,  308,  320,
      324,  325,  326,  304,  327,  328,  329,  330,  331,  332,

      333,  199,  334,  335,  182,  336,  321,  322,  337,  338,
      339,  340,  323,  341,  342,  635,  343,  344,  345,  324,
      325,  346,  326,  327,  328,  347,  329,  330,  331,  332,
      333,  334,  348,  335,  336,  349,  351,  337,  338,  339,
      350,  340,  341,  352,  342,  343,  344,  345,  353,  354,
      346,  355,  356,  357,  358,  347,  359,  360,  361,  362,
      366,  348,  363,  364,  365,  349,  351,  369,  367,  350,
      370,  371,  352,  368,  372,  373,  374,  353,  354,  375,
      355,  356,  357,  358,  376,  359,  360,  377,  361,  362,
      366,  363,  364,  365,  378,  379,  380,  369,  367,  370,

      381,  371,  621,  368,  372,  373,  374,  635,  375,  615,
      395,  612,  609,  606,  376,  603,  377,  621,  635,  396,
      597,  397,  398,  378,  379,  615,  380,  612,  609,  381,
      383,  383,  383,  383,  383,  383,  383,  383,   80,  395,
      384,  384,  384,  384,  384,  384,  384,  384,   82,  396,
      397,  399,  398,  385,  385,  385,  385,  385,  385,  672,
      400,  385,  385,  385,  385,  385,  385,  385,  385,  392,
      392,  392,  392,  392,  392,  392,  392,  401,  403,  402,
      399,  606,  407,  385,  385,  385,  385,  385,  385,  400,
      408,  409,  410,  603,  411,  412,  413,  414,  404,  415,

      417,  418,  419,  639,  420,  421,  423,  401,  402,  405,
      406,  407,  422,  424,  425,  426,  427,  428,  430,  408,
      409,  429,  410,  411,  431,  412,  413,  416,  404,  417,
      418,  432,  419,  420,  433,  421,  423,  434,  405,  406,
      435,  422,  424,  425,  436,  426,  427,  428,  430,  437,
      429,  438,  621,  431,  439,  585,  416,  635,  597,  615,
      578,  432,  452,  433,  453,  454,  434,  455,  456,  435,
      464,  465,  466,  468,  436,  467,  469,  612,  437,  575,
      470,  438,  441,  439,  383,  383,  383,  383,  383,  383,
      383,  383,  452,  453,  454,  462,  455,  456,  471,  472,

      464,  465,  466,  468,  467,  473,  469,  474,  463,  470,
      475,  476,  609,  477,  478,  479,  480,  481,  481,  481,
      481,  481,  481,  481,  481,  462,  493,  471,  472,  494,
      495,  499,  501,  502,  473,  505,  474,  463,  503,  504,
      475,  476,  477,  478,  479,  480,  506,  507,  508,  509,
      572,  510,  511,  606,  569,  493,  603,  621,  494,  495,
      499,  501,  502,  524,  527,  505,  528,  503,  504,  529,
      530,  585,  547,  548,  618,  506,  507,  508,  563,  509,
      510,  511,  481,  481,  481,  481,  481,  481,  481,  481,
      581,  597,  524,  527,  562,  528,  615,  578,  529,  612,

      530,  547,  575,  548,  609,  572,  606,  563,  569,  603,
      601,  585,  552,  597,  562,  578,  542,  575,  539,  581,
       69,   69,  572,   69,   69,   70,  536,   70,   70,   70,
       73,  569,   73,   73,   73,   90,  585,   90,   90,   90,
       83,   83,  189,  189,  189,  189,  189,  194,  194,  309,
      309,  314,  314,  386,  386,  387,  387,  389,  389,  393,
      393,  443,  443,  444,  444,  447,  447,  449,  449,  450,
      450,  483,  483,  484,  484,  486,  486,  488,  488,  489,
      489,  491,  491,  513,  513,  514,  514,  517,  517,  519,
      519,  521,  521,  522,  522,  532,  532,  533,  533,  535,

      535,  537,  537,  538,  538,  540,  540,  541,  541,  543,
      543,  550,  550,  551,  551,  554,  554,  556,  556,  558,
      558,  560,  560,  561,  561,  565,  565,  566,  566,  568,
      568,  570,  570,  571,  571,  573,  573,  574,  574,  576,
      576,  577,  577,  579,  579,  583,  583,  584,  584,  587,
      587,  589,  589,  591,  591,  593,  593,  595,  595,  596,
      596,  599,  599,  600,  600,  602,  602,  604,  604,  605,
      605,  607,  607,  608,  608,  610,  610,  611,  611,  613,
      613,  614,  614,  616,  616,  619,  619,  620,  620,  623,
      623,  625,  625,  627,  627,  629,  629,  631,  631,  633,

      633,  634,  634,  637,  637,  638,  638,  641,  641,  643,
      643,  645,  645,  647,  647,  649,  649,  651,  651,  653,
      653,  661,  661,  552,  582,  562,  523,  578,  542,  575,
      539,  572,  536,  569,  567,  552,  515,  562,  523,  542,
      490,  539,  487,  536,  552,  515,  549,  523,  451,  542,
      490,  539,  487,  536,  534,  515,  445,  526,  525,  523,
      451,  490,  390,  487,  515,  445,  512,  500,  498,  497,
      496,  451,  315,  490,  390,  487,  485,  445,  310,  461,
      451,  315,  442,  390,  445,  310,  442,  442,  440,  315,
      390,  388,  310,  315,  310,  305,  190,  185,  184,  211,

      210,  209,   92,   91,  195,  190,   78,   77,   76,   75,
      187,   72,   71,  186,  185,  184,   92,   91,   78,   77,
       76,   75,   72,   71,  185,  184,   92,   91,   89,   77,
       76,   75,   74,   72,   71,  672,    3,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672
    } ;

static const flex_int32_t yy_chk[1626] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    5,    5,
        5,    6,    6,    6,    7,    7,    7,   22,   19,    7,

        7,   32,   29,   29,    7,    7,   19,    7,   32,    7,
       29,   35,  826,   22,   35,   40,   48,   33,   74,   35,
        7,   46,    7,   50,  248,   32,  248,   22,  825,   32,
       33,   84,   84,   33,  824,   46,   36,   36,   32,   33,
       35,   36,   22,   35,   40,   87,   48,   95,   35,   36,
      823,   46,    7,   50,   32,   57,   57,   57,   32,  416,
       33,  416,   33,   74,   46,  822,   36,   36,   33,  100,
      100,   36,   37,   37,  821,   87,   37,   95,   36,    7,
       20,   98,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   93,   74,   42,   38,   20,   20,   20,   20,   20,

       20,   96,   37,   37,   38,   47,   37,   42,   38,   94,
       42,   98,   47,   99,  105,  106,  820,   96,   20,   97,
       93,  196,  196,   42,   38,   20,   20,   20,   20,   20,
       20,   96,   97,   38,  819,   47,   42,   38,   94,   42,
      107,   47,   99,  109,  105,  106,   96,   20,   21,   97,
       21,   21,   21,   21,   21,   21,   21,   21,   21,  312,
      312,   97,  110,   21,   21,   21,   21,   21,   21,  524,
      107,  524,  109,  111,  818,   58,   58,   58,  817,   21,
       58,   58,  816,  814,  813,   58,   58,  812,   58,  108,
       58,  110,  811,   21,   21,   21,   21,   21,   21,  108,

       39,   58,  111,   58,   39,  810,  809,   39,   21,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   39,  108,
      112,  113,   28,   28,   28,   28,   28,   28,  108,  114,
       39,  808,  116,   58,   39,   28,  112,   39,  117,   28,
       28,  119,   28,  402,  806,  402,  804,   39,  402,  402,
      112,  113,   28,   28,   28,   28,   28,   28,  802,  114,
       58,  116,  118,  121,   28,  112,  120,  117,   28,   28,
      119,   28,   30,   30,   30,   30,   30,   30,   30,   30,
       30,  124,  127,  126,  123,   30,   30,   30,   30,   30,
       30,  128,  118,  121,  129,  120,   30,  126,   30,   30,

       30,  123,  125,   30,  125,  130,  131,   30,  800,  798,
      124,  796,  127,  126,  123,   30,   30,   30,   30,   30,
       30,  128,  794,  129,  791,   30,  126,   30,   30,   30,
      123,  125,   30,  125,  130,  131,   30,   31,   31,   31,
       31,   31,   31,   31,   31,   31,  133,  136,  144,  135,
       31,   31,   31,   31,   31,   31,  145,  134,   31,  134,
      788,  786,  784,   31,   31,   31,  135,   31,   31,  137,
      139,  140,   41,  148,   41,  133,  136,   41,  144,  135,
       31,   31,   31,   31,   31,   31,  145,  134,   31,   41,
       41,   41,   31,   31,   31,  135,   31,   31,  137,  139,

      140,  782,   41,  148,   41,  150,  122,   41,   43,  122,
       43,   43,   43,  780,  141,  122,  134,  142,   41,   41,
       41,   43,  146,  147,  152,  778,   43,   80,   80,   80,
       80,   80,   80,   80,   80,  150,  122,  153,   43,  122,
       43,   43,   43,  141,  122,  775,  142,  762,  759,  757,
       43,  146,  147,  149,  152,   43,   44,  154,  755,  149,
       44,  753,  151,   44,   44,  157,  153,  155,   44,  151,
       83,   44,   83,   83,   83,   83,   83,   83,   83,   83,
       44,  751,  156,  149,  158,  158,   44,  154,  149,  159,
       44,  151,  160,   44,   44,  157,  155,   44,  151,  161,

       44,   86,   86,   86,   86,   86,   86,   86,   86,   44,
       45,  156,  162,  158,  158,   45,   45,  163,  165,  159,
       45,  160,   45,   45,  164,   45,  167,   45,  169,  161,
      166,  748,   45,  171,  391,  391,  737,  734,  732,  730,
       45,  162,  391,  728,  166,   45,   45,  163,  165,   45,
      725,   45,   45,  164,   45,  167,   45,  716,  169,  713,
      166,   45,   81,  171,   81,   81,   81,   81,   81,   81,
       81,   81,   81,  166,  172,  174,  175,   81,   81,   81,
       81,   81,   81,  168,  711,  170,  168,  176,  170,  177,
      168,  173,  178,  709,  179,  180,  706,  181,  183,  173,

      699,  696,  694,  172,  174,  175,  691,   81,   81,   81,
       81,   81,   81,  168,  170,  168,  176,  170,  177,  168,
      200,  173,  178,  179,  686,  180,  181,  183,  191,  173,
      191,  191,  191,  191,  191,  191,  191,  191,  192,  684,
      192,  192,  192,  192,  192,  192,  192,  192,  192,  200,
      201,  202,  203,  192,  192,  192,  192,  192,  192,  193,
      204,  193,  193,  193,  193,  193,  193,  193,  193,  197,
      197,  197,  197,  197,  197,  197,  197,  205,  207,  201,
      202,  203,  208,  192,  192,  192,  192,  192,  192,  204,
      213,  214,  215,  682,  216,  218,  220,  221,  222,  224,

      226,  681,  227,  228,  678,  229,  205,  207,  231,  234,
      236,  238,  208,  239,  240,  661,  241,  242,  243,  213,
      214,  244,  215,  216,  218,  249,  220,  221,  222,  224,
      226,  227,  250,  228,  229,  252,  255,  231,  234,  236,
      253,  238,  239,  256,  240,  241,  242,  243,  257,  258,
      244,  259,  262,  263,  266,  249,  267,  269,  270,  271,
      277,  250,  272,  273,  274,  252,  255,  281,  278,  253,
      283,  286,  256,  278,  289,  291,  294,  257,  258,  295,
      259,  262,  263,  266,  297,  267,  269,  299,  270,  271,
      277,  272,  273,  274,  300,  301,  302,  281,  278,  283,

      303,  286,  653,  278,  289,  291,  294,  651,  295,  649,
      316,  647,  645,  643,  297,  641,  299,  637,  634,  317,
      633,  319,  320,  300,  301,  631,  302,  629,  627,  303,
      306,  306,  306,  306,  306,  306,  306,  306,  307,  316,
      307,  307,  307,  307,  307,  307,  307,  307,  307,  317,
      319,  321,  320,  307,  307,  307,  307,  307,  307,  308,
      324,  308,  308,  308,  308,  308,  308,  308,  308,  313,
      313,  313,  313,  313,  313,  313,  313,  325,  328,  327,
      321,  625,  329,  307,  307,  307,  307,  307,  307,  324,
      334,  337,  338,  623,  340,  344,  345,  346,  328,  346,

      347,  349,  352,  621,  353,  355,  358,  325,  327,  328,
      328,  329,  357,  359,  360,  361,  362,  363,  365,  334,
      337,  364,  338,  340,  366,  344,  345,  346,  328,  347,
      349,  367,  352,  353,  368,  355,  358,  370,  328,  328,
      371,  357,  359,  360,  375,  361,  362,  363,  365,  377,
      364,  378,  620,  366,  380,  619,  346,  617,  616,  614,
      613,  367,  395,  368,  396,  397,  370,  398,  399,  371,
      405,  406,  409,  418,  375,  412,  419,  611,  377,  610,
      420,  378,  383,  380,  383,  383,  383,  383,  383,  383,
      383,  383,  395,  396,  397,  404,  398,  399,  424,  426,

      405,  406,  409,  418,  412,  428,  419,  430,  404,  420,
      432,  433,  608,  435,  437,  438,  439,  441,  441,  441,
      441,  441,  441,  441,  441,  404,  452,  424,  426,  454,
      456,  462,  464,  465,  428,  467,  430,  404,  466,  466,
      432,  433,  435,  437,  438,  439,  469,  470,  471,  473,
      607,  474,  479,  605,  604,  452,  602,  600,  454,  456,
      462,  464,  465,  499,  503,  467,  504,  466,  466,  505,
      509,  599,  527,  528,  598,  469,  470,  471,  548,  473,
      474,  479,  481,  481,  481,  481,  481,  481,  481,  481,
      563,  596,  499,  503,  595,  504,  594,  593,  505,  592,

      509,  527,  591,  528,  590,  589,  588,  548,  587,  586,
      585,  584,  583,  580,  579,  577,  576,  574,  573,  563,
      673,  673,  571,  673,  673,  674,  570,  674,  674,  674,
      675,  568,  675,  675,  675,  676,  566,  676,  676,  676,
      677,  677,  679,  679,  679,  679,  679,  680,  680,  683,
      683,  685,  685,  687,  687,  688,  688,  689,  689,  690,
      690,  692,  692,  693,  693,  695,  695,  697,  697,  698,
      698,  700,  700,  701,  701,  702,  702,  703,  703,  704,
      704,  705,  705,  707,  707,  708,  708,  710,  710,  712,
      712,  714,  714,  715,  715,  717,  717,  718,  718,  719,

      719,  720,  720,  721,  721,  722,  722,  723,  723,  724,
      724,  726,  726,  727,  727,  729,  729,  731,  731,  733,
      733,  735,  735,  736,  736,  738,  738,  739,  739,  740,
      740,  741,  741,  742,  742,  743,  743,  744,  744,  745,
      745,  746,  746,  747,  747,  749,  749,  750,  750,  752,
      752,  754,  754,  756,  756,  758,  758,  760,  760,  761,
      761,  763,  763,  764,  764,  765,  765,  766,  766,  767,
      767,  768,  768,  769,  769,  770,  770,  771,  771,  772,
      772,  773,  773,  774,  774,  776,  776,  777,  777,  779,
      779,  781,  781,  783,  783,  785,  785,  787,  787,  789,

      789,  790,  790,  792,  792,  793,  793,  795,  795,  797,
      797,  799,  799,  801,  801,  803,  803,  805,  805,  807,
      807,  815,  815,  565,  564,  561,  560,  559,  558,  557,
      556,  555,  554,  553,  552,  551,  550,  544,  543,  541,
      540,  538,  537,  535,  533,  532,  531,  522,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  502,  501,  492,
      491,  489,  488,  486,  484,  483,  482,  463,  459,  458,
      457,  450,  449,  448,  447,  446,  445,  444,  443,  403,
      394,  393,  392,  389,  387,  386,  385,  384,  382,  314,
      311,  310,  309,  199,  194,  190,  189,  185,  184,  103,

      102,  101,   92,   91,   82,   79,   78,   77,   76,   75,
       73,   72,   71,   69,   68,   67,   66,   65,   64,   63,
       62,   61,   60,   59,   55,   53,   27,   25,   23,   18,
       16,   15,   12,   11,   10,    3,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,

      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "trafgen_lexer.l"
/*
 * netsniff-ng - the packet sniffing beast
 * By Daniel Borkmann <daniel@netsniff-ng.org>
 * Copyright 2012 Daniel Borkmann <dborkma@tik.ee.ethz.ch>,
 * Swiss federal institute of technology (ETH Zurich)
 * Subject to the GPL, version 2.
 */
/* lex-func-prefix: yy */
#line 12 "trafgen_lexer.l"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <stdbool.h>
#include <arpa/inet.h>

#include "trafgen_parser.tab.h"
#include "xmalloc.h"
#include "built_in.h"
#include "str.h"

extern void yyerror(const char *);

static char *try_convert_shellcode(char *sstr)
{
	bool found_any = false;
	char *bstr, *ostr = sstr, *hay, *orig = sstr;
	size_t j = 0, blen, slen = strlen(sstr), tot = 0;
	const char *needle = "\\x";

	sstr++;
	slen -= 2;

	if (slen % 4 != 0)
		return orig;

	blen = slen / 4;
	hay = sstr;
	while ((hay = strstr(hay, needle)) != NULL ) {
		hay += strlen(needle) + 2;
		found_any = true;
		tot++;
	}

	if (blen != tot || !found_any)
		return orig;

	blen += 2;
	bstr = xzmalloc(blen);

	bstr[j++] = '\"';
	while (j < blen - 1)
		bstr[j++] = (uint8_t) strtoul(sstr + 2, &sstr, 16);
	bstr[j++] = '\"';

	xfree(ostr);
	return bstr;
}

#line 1121 "trafgen/trafgen_lexer.yy.c"
#define YY_NO_INPUT 1
/* rules taken from nftables scanner.l */
#line 1124 "trafgen/trafgen_lexer.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 132 "trafgen_lexer.l"


#line 1342 "trafgen/trafgen_lexer.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 673 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1537 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 134 "trafgen_lexer.l"
{ return K_CPU; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 135 "trafgen_lexer.l"
{ return K_FILL; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 136 "trafgen_lexer.l"
{ return K_RND; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 137 "trafgen_lexer.l"
{ return K_CSUMIP; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 138 "trafgen_lexer.l"
{ return K_CSUMIP; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 139 "trafgen_lexer.l"
{ return K_CSUMIP; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 140 "trafgen_lexer.l"
{ return K_CSUMIP; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 141 "trafgen_lexer.l"
{ return K_CSUMIP; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 142 "trafgen_lexer.l"
{ return K_CSUMUDP; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 143 "trafgen_lexer.l"
{ return K_CSUMTCP; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 144 "trafgen_lexer.l"
{ return K_CSUMUDP6; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 145 "trafgen_lexer.l"
{ return K_CSUMTCP6; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 146 "trafgen_lexer.l"
{ return K_CSUMICMP6; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 147 "trafgen_lexer.l"
{ return K_DRND; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 148 "trafgen_lexer.l"
{ return K_DINC; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 149 "trafgen_lexer.l"
{ return K_DDEC; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 150 "trafgen_lexer.l"
{ return K_SEQINC; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 151 "trafgen_lexer.l"
{ return K_SEQDEC; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 152 "trafgen_lexer.l"
{ return K_CONST8; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 153 "trafgen_lexer.l"
{ return K_CONST16; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 154 "trafgen_lexer.l"
{ return K_CONST32; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 155 "trafgen_lexer.l"
{ return K_CONST64; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 157 "trafgen_lexer.l"
{ return K_PROT; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 158 "trafgen_lexer.l"
{ return K_TC; }
	YY_BREAK
/* Ethernet */
case 25:
YY_RULE_SETUP
#line 161 "trafgen_lexer.l"
{ return K_DADDR; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 162 "trafgen_lexer.l"
{ return K_SADDR; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 163 "trafgen_lexer.l"
{ return K_ETYPE; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 164 "trafgen_lexer.l"
{ return K_TYPE; }
	YY_BREAK
/* PFC/IEEE 802.3X PAUSE */
case 29:
YY_RULE_SETUP
#line 167 "trafgen_lexer.l"
{ return K_TIME; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 168 "trafgen_lexer.l"
{ return K_PRIO; }
	YY_BREAK
/* VLAN (802.1Q & 802.1ad) */
case 31:
YY_RULE_SETUP
#line 171 "trafgen_lexer.l"
{ return K_TPID; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 172 "trafgen_lexer.l"
{ return K_TCI; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 173 "trafgen_lexer.l"
{ return K_PCP; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 174 "trafgen_lexer.l"
{ return K_DEI; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 175 "trafgen_lexer.l"
{ return K_1AD; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 176 "trafgen_lexer.l"
{ return K_1Q; }
	YY_BREAK
/* MPLS (Multi Protocol Label Switching) */
case 37:
YY_RULE_SETUP
#line 179 "trafgen_lexer.l"
{ return K_LABEL; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 180 "trafgen_lexer.l"
{ return K_LAST; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 181 "trafgen_lexer.l"
{ return K_EXP; }
	YY_BREAK
/* ARP */
case 40:
YY_RULE_SETUP
#line 184 "trafgen_lexer.l"
{ return K_SHA; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 185 "trafgen_lexer.l"
{ return K_SPA; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 186 "trafgen_lexer.l"
{ return K_THA; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 187 "trafgen_lexer.l"
{ return K_TPA; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 188 "trafgen_lexer.l"
{ return K_REQUEST; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 189 "trafgen_lexer.l"
{ return K_REPLY; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 190 "trafgen_lexer.l"
{ return K_OPER; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 191 "trafgen_lexer.l"
{ return K_HTYPE; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 192 "trafgen_lexer.l"
{ return K_PTYPE; }
	YY_BREAK
/* IPv4 */
case 49:
YY_RULE_SETUP
#line 195 "trafgen_lexer.l"
{ return K_IHL; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 196 "trafgen_lexer.l"
{ return K_VER; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 197 "trafgen_lexer.l"
{ return K_TTL; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 198 "trafgen_lexer.l"
{ return K_DSCP; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 199 "trafgen_lexer.l"
{ return K_ECN; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 200 "trafgen_lexer.l"
{ return K_TOS; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 201 "trafgen_lexer.l"
{ return K_LEN; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 202 "trafgen_lexer.l"
{ return K_ID; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 203 "trafgen_lexer.l"
{ return K_FLAGS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 204 "trafgen_lexer.l"
{ return K_FRAG; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 205 "trafgen_lexer.l"
{ return K_CSUM; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 206 "trafgen_lexer.l"
{ return K_DF; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 207 "trafgen_lexer.l"
{ return K_MF; }
	YY_BREAK
/* IPv6 */
case 62:
YY_RULE_SETUP
#line 210 "trafgen_lexer.l"
{ return K_FLOW; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 211 "trafgen_lexer.l"
{ return K_NEXT_HDR; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 212 "trafgen_lexer.l"
{ return K_HOP_LIMIT; }
	YY_BREAK
/* ICMPv4 */
case 65:
YY_RULE_SETUP
#line 216 "trafgen_lexer.l"
{ return K_ADDR; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 217 "trafgen_lexer.l"
{ return K_MTU; }
	YY_BREAK
/* ICMPv6 */
case 67:
YY_RULE_SETUP
#line 220 "trafgen_lexer.l"
{ return K_CODE; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 221 "trafgen_lexer.l"
{ return K_ECHO_REQUEST; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 222 "trafgen_lexer.l"
{ return K_ECHO_REPLY; }
	YY_BREAK
/* UDP */
case 70:
YY_RULE_SETUP
#line 225 "trafgen_lexer.l"
{ return K_SPORT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 226 "trafgen_lexer.l"
{ return K_DPORT; }
	YY_BREAK
/* TCP */
case 72:
YY_RULE_SETUP
#line 229 "trafgen_lexer.l"
{ return K_SEQ; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 230 "trafgen_lexer.l"
{ return K_ACK_SEQ; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 231 "trafgen_lexer.l"
{ return K_DOFF; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 232 "trafgen_lexer.l"
{ return K_CWR; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 233 "trafgen_lexer.l"
{ return K_ECE; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 234 "trafgen_lexer.l"
{ return K_URG; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 235 "trafgen_lexer.l"
{ return K_ACK; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 236 "trafgen_lexer.l"
{ return K_PSH; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 237 "trafgen_lexer.l"
{ return K_RST; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 238 "trafgen_lexer.l"
{ return K_SYN; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 239 "trafgen_lexer.l"
{ return K_FIN; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 240 "trafgen_lexer.l"
{ return K_WINDOW; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 241 "trafgen_lexer.l"
{ return K_URG_PTR; }
	YY_BREAK
/* DNS */
case 85:
YY_RULE_SETUP
#line 244 "trafgen_lexer.l"
{ return K_QR; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 245 "trafgen_lexer.l"
{ return K_AANSWER; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 246 "trafgen_lexer.l"
{ return K_TRUNC; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 247 "trafgen_lexer.l"
{ return K_RAVAIL; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 248 "trafgen_lexer.l"
{ return K_RDESIRED; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 249 "trafgen_lexer.l"
{ return K_ZERO; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 250 "trafgen_lexer.l"
{ return K_RCODE; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 251 "trafgen_lexer.l"
{ return K_QDCOUNT; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 252 "trafgen_lexer.l"
{ return K_ANCOUNT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 253 "trafgen_lexer.l"
{ return K_NSCOUNT; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 254 "trafgen_lexer.l"
{ return K_ARCOUNT; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 255 "trafgen_lexer.l"
{ return K_NAME; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 256 "trafgen_lexer.l"
{ return K_CLASS; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 257 "trafgen_lexer.l"
{ return K_DATA; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 258 "trafgen_lexer.l"
{ return K_QUERY; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 259 "trafgen_lexer.l"
{ return K_ANSWER; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 260 "trafgen_lexer.l"
{ return K_AUTH; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 261 "trafgen_lexer.l"
{ return K_ADD; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 262 "trafgen_lexer.l"
{ return K_NS; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 263 "trafgen_lexer.l"
{ return K_CNAME; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 264 "trafgen_lexer.l"
{ return K_PTR; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 266 "trafgen_lexer.l"
{ return K_ETH; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 267 "trafgen_lexer.l"
{ return K_PAUSE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 268 "trafgen_lexer.l"
{ return K_PFC; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 269 "trafgen_lexer.l"
{ return K_VLAN; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 270 "trafgen_lexer.l"
{ return K_MPLS; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 271 "trafgen_lexer.l"
{ return K_ARP; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 272 "trafgen_lexer.l"
{ return K_IP4; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 273 "trafgen_lexer.l"
{ return K_IP6; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 274 "trafgen_lexer.l"
{ return K_ICMP4; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 275 "trafgen_lexer.l"
{ return K_ICMP6; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 276 "trafgen_lexer.l"
{ return K_UDP; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 277 "trafgen_lexer.l"
{ return K_TCP; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 278 "trafgen_lexer.l"
{ return K_DNS; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 280 "trafgen_lexer.l"
{ return '-'; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 281 "trafgen_lexer.l"
{ return '+'; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 282 "trafgen_lexer.l"
{ return '*'; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 283 "trafgen_lexer.l"
{ return '/'; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 284 "trafgen_lexer.l"
{ return '%'; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 285 "trafgen_lexer.l"
{ return '&'; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 286 "trafgen_lexer.l"
{ return '|'; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 287 "trafgen_lexer.l"
{ return '<'; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 288 "trafgen_lexer.l"
{ return '>'; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 289 "trafgen_lexer.l"
{ return '^'; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 290 "trafgen_lexer.l"
{ return '{'; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 291 "trafgen_lexer.l"
{ return '}'; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 292 "trafgen_lexer.l"
{ return '('; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 293 "trafgen_lexer.l"
{ return ')'; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 294 "trafgen_lexer.l"
{ return '['; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 295 "trafgen_lexer.l"
{ return ']'; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 296 "trafgen_lexer.l"
{ return ','; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 297 "trafgen_lexer.l"
{ return ':'; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 298 "trafgen_lexer.l"
{ return '='; }
	YY_BREAK
case 138:
/* rule 138 can match eol */
YY_RULE_SETUP
#line 300 "trafgen_lexer.l"
{ yylineno++; }
	YY_BREAK
case 139:
/* rule 139 can match eol */
YY_RULE_SETUP
#line 302 "trafgen_lexer.l"
{ yylval.str = try_convert_shellcode(xstrdup(yytext));
		  return string; }
	YY_BREAK
case 140:
/* rule 140 can match eol */
YY_RULE_SETUP
#line 305 "trafgen_lexer.l"
{ return K_WHITE; }
	YY_BREAK
case 141:
/* rule 141 can match eol */
YY_RULE_SETUP
#line 307 "trafgen_lexer.l"
{ return K_COMMENT; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 309 "trafgen_lexer.l"
{ return K_COMMENT; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 311 "trafgen_lexer.l"
{ yylval.number = strtoul(yytext + (yytext[0] == 'x' ? 1 : 0),
					  NULL, 16);
		  return number; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 315 "trafgen_lexer.l"
{ yylval.number = strtol(yytext, NULL, 10);
		  return number; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 318 "trafgen_lexer.l"
{ yylval.number = strtol(yytext + 1, NULL, 8);
		  return number; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 321 "trafgen_lexer.l"
{ yylval.number = strtol(yytext + (yytext[0] == 'b' ? 1 : 2),
					 NULL, 2);
		  return number; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 325 "trafgen_lexer.l"
{ yylval.number = (uint8_t) (*yytext);
		  return number; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 328 "trafgen_lexer.l"
{ if (str2mac(yytext, yylval.mac, 6))
			panic("Failed to parse MAC address %s\n", yytext);
		  return mac; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 332 "trafgen_lexer.l"
{ if (inet_pton(AF_INET, yytext, &yylval.ip4_addr) != 1)
			panic("Failed to parse IPv4 address %s\n", yytext);
		  return ip4_addr; };
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 336 "trafgen_lexer.l"
{ if (inet_pton(AF_INET6, yytext, &yylval.ip6_addr) != 1)
			panic("Failed to parse IPv6 address %s\n", yytext);
		  return ip6_addr; };
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 340 "trafgen_lexer.l"
{ yylval.number = strtol(yytext + 3, NULL, 16);
		  return number; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 343 "trafgen_lexer.l"
{ yylval.number = (uint8_t) (*(yytext + 1));
		  return number; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 346 "trafgen_lexer.l"
{/* NOP */}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 347 "trafgen_lexer.l"
{ printf("Unknown character '%s'", yytext);
		  yyerror("lex Unknown character"); }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 350 "trafgen_lexer.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2207 "trafgen/trafgen_lexer.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 673 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 673 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 672);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 350 "trafgen_lexer.l"


